//
// File Merger (program entry point)
//
// Written by Maxwell Sayles.  Copyright (C) 2000.
//

#include <windows.h>
#include <commctrl.h>
#include "resource.h"
#include "FileMerger_Dialog.hpp"


static char* defaultOutputFileName = "C:\\out.dat";

static const char* destinationFileString = "Destination File";
static const char* deleteAfterProcessedString = "Delete after processed";


//
// program entry
// load values from registry
// create dialog box
// write values to registry
//
int WINAPI WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow )
{
	InitCommonControls (); // needed for progress bar

	// read registry settings
	char* destinationFileName = defaultOutputFileName;
	bool deleteAfterProcessed = false;

	// open our key
	HKEY hKeyFileMerger;
	LONG result = RegOpenKeyEx (HKEY_CURRENT_USER, "Software\\I-Media\\FileMerger", 0, KEY_QUERY_VALUE, &hKeyFileMerger);

	if (result == ERROR_SUCCESS)
	{
		// read destination file
		DWORD dataSize = 0;
		DWORD type = 0;
		result = RegQueryValueEx (hKeyFileMerger, destinationFileString, 0, &type, NULL, &dataSize);
		if ((result == ERROR_SUCCESS) &&
				(type == REG_SZ))
		{
			destinationFileName = new char [dataSize];
			result = RegQueryValueEx (hKeyFileMerger, destinationFileString, 0, NULL, (LPBYTE)(destinationFileName), &dataSize);
			if (result != ERROR_SUCCESS)
			{
				delete[] destinationFileName;
				destinationFileName = defaultOutputFileName;
			}
		}

		// read 'delete after processed' checkbox
		result = RegQueryValueEx (hKeyFileMerger, deleteAfterProcessedString, 0, &type, NULL, &dataSize);
		if ((result == ERROR_SUCCESS) &&
				(type == REG_SZ))
		{
			char* checkValue = new char [dataSize];
			result = RegQueryValueEx (hKeyFileMerger, deleteAfterProcessedString, 0, NULL, (LPBYTE)(checkValue), &dataSize);
			if (result == ERROR_SUCCESS)
			{
				deleteAfterProcessed = (strcmp (checkValue, "Yes") == 0);
			}
			delete[] checkValue;
		}

		// close key
		RegCloseKey (hKeyFileMerger);
	}

	// create dialog
	FileMerger_Dialog* dialog = new FileMerger_Dialog (destinationFileName, deleteAfterProcessed);
	DialogBoxParam (hInstance, MAKEINTRESOURCE( IDD_FILE_MERGER ), HWND_DESKTOP, (DLGPROC)(FileMerger_Dialog::DialogProc), (LPARAM)(dialog));


	// write out registry settings
	result = RegCreateKeyEx (HKEY_CURRENT_USER, "Software\\I-Media\\FileMerger", 0, NULL, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, 0, &hKeyFileMerger, NULL);
	if (result == ERROR_SUCCESS)
	{
		// write subkey data
		RegSetValueEx (hKeyFileMerger, destinationFileString, 0, REG_SZ, (CONST BYTE*)(dialog->destinationFileName), (strlen (dialog->destinationFileName) + 1));

		char* value = ((dialog->deleteAfterProcessed) ? "Yes" : "No");
		RegSetValueEx (hKeyFileMerger, deleteAfterProcessedString, 0, REG_SZ, (CONST BYTE*)(value), (strlen (value) + 1));

		// close key
		RegCloseKey (hKeyFileMerger);
	}

	delete dialog;

	// clean-up
	if (destinationFileName != defaultOutputFileName)
	{
		delete[] destinationFileName;
	}

	return 0;
}